#==============================================================================
# package      DE_EPAGES::Order::API::Constants
# state        public
# description  Constants for cartridge Order
#==============================================================================
package DE_EPAGES::Order::API::Constants;
use base Exporter;

use strict;
use DE_EPAGES::Core::API::EpagesConfig qw ( EpagesConfig );

our @EXPORT_OK = qw(
    CLASS_MAP
    COUNTRYID_ITALY
    FISCALCODE_LIMIT
    ORDER_STATUS_ATTRIBUTES
    CLASSICCHECKOUT
    MULTISTEPCHECKOUT
    MAX_DAYS_OF_LATEST_ORDER_FOR_UNITY_MIGRATION
    PDF_DENSITY
    UNITY_REGISTER_SESSION_SCRIPT_PAGE_TYPE
    CART_PATCH_PARTIALLY_COMPLETE
    CART_PATCH_COMPLETE
    DELIVERY_TRESHOLD
);

#========================================================================================
# global       CLASS_MAP | Maps attribute names to class aliases:<ul>
#                   <li>LineItems      => LineItemSales
#                   <li>SalesDiscounts => LineItemSalesDiscount
#                   <li>Discounts      => LineItemDiscount
#                   <li>Taxes          => LineItemTax
#                   <li>TaxesDigital   => LineItemTaxDigital
#                   <li>Shipping       => LineItemShipping
#                   <li>Payment        => LineItemPayment
#                   <li>PaymentDiscount=> LineItemPaymentDiscount
#                   <li>Orders         => CustomerOrder
#                   <li>PrePayments    => LineItemPrePayment
#               </ul> | ref.hash
#========================================================================================
use constant CLASS_MAP => {
    'Positions'      => 'LineItem',
    'LineItems'      => 'LineItemSales',
    'SalesDiscounts' => 'LineItemSalesDiscount',
    'Discounts'      => 'LineItemDiscount',
    'Taxes'          => 'LineItemTax',
    'TaxesDigital'   => 'LineItemTaxDigital',
    'Shipping'       => 'LineItemShipping',
    'Payment'        => 'LineItemPayment',
    'PaymentDiscount'=> 'LineItemPaymentDiscount',
    'Orders'         => 'CustomerOrder',
    'Statics'        => 'LineItemStatic',
    'PrePayments'    => 'LineItemPrePayment',
};

#========================================================================================
# global       ORDER_STATUS_ATTRIBUTES | list of order status attributes:
#                       ViewedOn CancelledOn, ...
#                       | list
#========================================================================================
use constant ORDER_STATUS_ATTRIBUTES => qw(ViewedOn CancelledOn InProcessOn PendingOn
    ReadyForShippingOn PartlyDispatchedOn DispatchedOn ShippedOn PartlyInvoicedOn
    InvoicedOn PartlyPaidOn PaidOn ClosedOn ArchivedOn ReturnedOn);

#========================================================================================
# global       FISCALCODE_LIMIT | limit for the italian fiscal code; if the grand total
#                                       value of a basket goes over this value the fiscal
#                                       code is mandatory for an italian order on an
#                                       italian shop
#                       | int
#========================================================================================
use constant FISCALCODE_LIMIT => 3600;

#========================================================================================
# global       COUNTRYID_ITALY | country id for italy
#                       | int
#========================================================================================
use constant COUNTRYID_ITALY => 380;

use constant CLASSICCHECKOUT => 0;
use constant MULTISTEPCHECKOUT => 1;

#========================================================================================
# global       MAX_DAYS_OF_LATEST_ORDER_FOR_UNITY_MIGRATION | maximum amount of days of
#                       the latest order of a shop that is still allowed for a Unity
#                       migration
#========================================================================================
sub MAX_DAYS_OF_LATEST_ORDER_FOR_UNITY_MIGRATION() { ## no critic qw(RequireCommentForExportedFunctions)
    return EpagesConfig()->get('DE_EPAGES::Order', 'MaxDaysOfLatestOrderForUnityMigration', 30);
}

#========================================================================================
# global       PDF_DENSITY | density for pdf print | int
#========================================================================================
use constant PDF_DENSITY => 96;

#========================================================================================
# global       UNITY_REGISTER_SESSION_SCRIPT_PAGE_TYPE | Unity PageType for the Script
#                   to register a session | string
#========================================================================================
use constant UNITY_REGISTER_SESSION_SCRIPT_PAGE_TYPE => 'UnitySF-RegisterSessionScript';

#========================================================================================
# global       CART_PATCH_PARTIALLY_COMPLETE | cart is patched only patially | string
#========================================================================================
use constant CART_PATCH_PARTIALLY_COMPLETE => 'PartiallyComplete';

#========================================================================================
# global       CART_PATCH_COMPLETE | cart patched completely | string
#========================================================================================
use constant CART_PATCH_COMPLETE => 'Complete';

#========================================================================================
# global       DELIVERY_TRESHOLD | The limit for delivery threshold which indicates that
#               the merchant can use the shop tax instead of the tax of the
#               delivery land | integer
#========================================================================================
use constant DELIVERY_TRESHOLD => 10000;


1;
