#========================================================================================
# package      DE_EPAGES::PriceList::API::Table::GlobalValueDiscount
# state        public
# base         Exporter
# description  interface for table GlobalValueDiscount
#========================================================================================
package DE_EPAGES::PriceList::API::Table::GlobalValueDiscount;
use base qw ( Exporter );

use DE_EPAGES::PriceList::DAL::GlobalValueDiscount qw (DAL_GetAllGlobalValueDiscountsByPriceListID);

use strict;

our @EXPORT_OK = qw (
  GetGlobalValueDiscountsByPriceListID
);


#========================================================================================
# function     GetGlobalValueDiscountsByPriceListID
# state        public
#----------------------------------------------------------------------------------------
# syntax       GetGlobalValueDiscountsByPriceListID($ShopID, $PriceListID);
#----------------------------------------------------------------------------------------
# description  Gets all the global value discount for a given ShopID and priceListID.
#----------------------------------------------------------------------------------------
# input        $ShopID | id of Shop | int
# input        $PriceListID| id of Pricelist | int
# $return       $ahGlobalValueDiscountsPricelist| with following keys:
#               <ul>
#                   <li>PriceListID   - pricelist id |   - int
#                   <li>Value - value |                  - decimal
#                   <li>Discount - discount |            - double
#                   <li>DiscountAbsolute - discount absolute |        - decimal
#               </ul> | reference to array of hashes
#========================================================================================
sub GetGlobalValueDiscountsByPriceListID {
    my ($ShopID, $PriceListID) = @_;

  return DAL_GetAllGlobalValueDiscountsByPriceListID($ShopID, $PriceListID);
}

1;
