#========================================================================================
# package      DE_EPAGES::PriceList::API::Table::QuantityDiscount
# state        public
# base         Exporter
# description  interface for table QuantityDiscount
#========================================================================================
package DE_EPAGES::PriceList::API::Table::QuantityDiscount;
use base qw ( Exporter );

use DE_EPAGES::PriceList::DAL::QuantityDiscount qw (DAL_GetAllQuantityDiscountsByPriceListID);

use strict;

our @EXPORT_OK = qw (
    GetQuantityDiscountsByPriceListID
);

#========================================================================================
# function     GetQuantityDiscountsByPriceListID
# state        public
#----------------------------------------------------------------------------------------
# syntax       GetQuantityDiscountsByPriceListID($ShopID, $PriceListID);
#----------------------------------------------------------------------------------------
# description  Gets all the quantity discount for all products and price lists for
# a given ShopID and priceListID.
#----------------------------------------------------------------------------------------
# input        $ShopID | id of Shop | int
# input        $PriceListID| id of PriceList | int
# $return       $ahQuantityDiscountPricelist| with following keys:
#               <ul>
#                   <li>PriceListID   - pricelist id |   - int
#                   <li>ProductID - product id |         - int
#                   <li>Quantity - quantity |            - decimal
#                   <li>Discount - discount |            - double
#               </ul> | reference to array of hashes
#========================================================================================
sub GetQuantityDiscountsByPriceListID {
    my ($ShopID, $PriceListID) = @_;

  return DAL_GetAllQuantityDiscountsByPriceListID($ShopID, $PriceListID);
}

1;
