#========================================================================================
# package      DE_EPAGES::PriceList::API::Table::ScalePrice
# state        public
# base         Exporter
# description  interface for table ScalePrice
#========================================================================================
package DE_EPAGES::PriceList::API::Table::ScalePrice;
use base qw ( Exporter );

use DE_EPAGES::PriceList::DAL::ScalePrice qw ( DAL_DeleteScalePrices DAL_GetAllScalePricesByPriceListID );
use DE_EPAGES::Core::API::TestParameter qw (TestInteger);

use strict;

our @EXPORT_OK = qw (
    DeleteScalePrices
    GetScalePricesByPriceListID
);

#========================================================================================
# function     DeleteScalePrices
# state        public
#----------------------------------------------------------------------------------------
# syntax       DeleteScalePrices($PriceListID);
#----------------------------------------------------------------------------------------
# description  Deletes all scale prices for a given price list id.
#----------------------------------------------------------------------------------------
# input        $PriceListID | id of price list | int
#========================================================================================
sub DeleteScalePrices {
    my ($PriceListID) = @_;

    TestInteger( 'PriceListID', $PriceListID );

    DAL_DeleteScalePrices($PriceListID);

    return;
}

#========================================================================================
# function     GetScalePricesByPriceListID
# state        public
#----------------------------------------------------------------------------------------
# syntax       GetScalePricesByPriceListID($ShopID, $PriceListID);
#----------------------------------------------------------------------------------------
# description  gets all the scale prices for all
# products and price lists for a given ShopID and priceListID.
#----------------------------------------------------------------------------------------
# input        $ShopID | id of Shop | int
# input        $PriceListID| id of Pricelist | int
# $return       $ahScalePricesPriceList| with following keys:
#               <ul>
#                   <li>PriceListID   - pricelist id |   - int
#                   <li>ProductID - product id |         - int
#                   <li>Quantity - quantity |            - decimal
#                   <li>Price - price |                  - decimal
#               </ul> | reference to array of hashes
#========================================================================================
sub GetScalePricesByPriceListID {
    my ($ShopID, $PriceListID) = @_;

    return DAL_GetAllScalePricesByPriceListID($ShopID, $PriceListID);
}

1;
