#========================================================================================
# package      DE_EPAGES::PriceList::DAL::GlobalValueDiscount
# state        public
# base         Exporter
# description  interface for table GlobalValueDoscount
#========================================================================================
package DE_EPAGES::PriceList::DAL::GlobalValueDiscount;
use base qw (Exporter);

use DE_EPAGES::Database::API::Connection qw (  GetCurrentDBHandle );
use DE_EPAGES::Core::API::Log qw ( GetLog );
use DE_EPAGES::Core::API::PerlTools qw ( UsePackage );

use strict;

our @EXPORT_OK = qw (
    DAL_GetAllGlobalValueDiscountsByPriceListID
);

#========================================================================================
# function     DAL_GetAllGlobalValueDiscountsByPriceListID
#----------------------------------------------------------------------------------------
# syntax       DAL_GetAllGlobalValueDiscountsByPriceListID($ShopID, $PriceListID);
#----------------------------------------------------------------------------------------
# description  Gets all the table entries for global value discount for a given shopID and
# pricelist ID.
#----------------------------------------------------------------------------------------
# input        $ShopID | shop id | int
# input        $PriceListID | pricelist id | int
# $return       $rahResult | with following keys:
#               <ul>
#                   <li>PriceListID   - pricelist id |   - int
#                   <li>Value - value |                  - decimal
#                   <li>Discount - discount |            - double
#                   <li>DiscountAbsolute - discount absolute |        - decimal
#               </ul> | reference to array of hashes
#========================================================================================
sub DAL_GetAllGlobalValueDiscountsByPriceListID {
    my ($ShopID, $PriceListID) = @_;

    return _CallDriver('GetGlobalValueDiscounts', $ShopID, $PriceListID);
}

sub _CallDriver {
    my ( $FunctionName, @Parameter ) = @_;
    my $dbi     = GetCurrentDBHandle();
    my $Package = 'DE_EPAGES::PriceList::DAL::' . $dbi->driverName . '::GlobalValueDiscount';
    UsePackage($Package);
    GetLog->debug("call $Package->$FunctionName()");
    return $Package->$FunctionName( $dbi, @Parameter );
}

1;
