#========================================================================================
# package      DE_EPAGES::PriceList::DAL::QuantityDiscount
# state        public
# base         Exporter
# description  interface for table QuantityDoscount
#========================================================================================
package DE_EPAGES::PriceList::DAL::QuantityDiscount;
use base qw (Exporter);

use DE_EPAGES::Database::API::Connection qw (  GetCurrentDBHandle );
use DE_EPAGES::Core::API::Log qw ( GetLog );
use DE_EPAGES::Core::API::PerlTools qw ( UsePackage );

use strict;

our @EXPORT_OK = qw (
    DAL_GetAllQuantityDiscountsByPriceListID
);

#========================================================================================
# function     DAL_GetAllQuantityDiscountsByPriceListID
#----------------------------------------------------------------------------------------
# syntax       DAL_GetAllQuantityDiscountsByPriceListID($ShopID, $PriceListID);
#----------------------------------------------------------------------------------------
# description  Gets all the table entries for quantity discount for a given shopID and
# pricelist ID.
#----------------------------------------------------------------------------------------
# input        $ShopID | shop id | int
# input        $PriceListID | pricelist id | int
# $return       $rahResult| with following keys:
#               <ul>
#                   <li>PriceListID   - pricelist id |   - int
#                   <li>ProductID - product id |         - int
#                   <li>Quantity - quantity |            - decimal
#                   <li>Discount - discount |            - double
#               </ul> | reference to array of hashes
#========================================================================================
sub DAL_GetAllQuantityDiscountsByPriceListID {
    my ($ShopID, $PriceListID) = @_;

    return _CallDriver('GetQuantityDiscounts', $ShopID, $PriceListID);
}

sub _CallDriver {
    my ( $FunctionName, @Parameter ) = @_;
    my $dbi     = GetCurrentDBHandle();
    my $Package = 'DE_EPAGES::PriceList::DAL::' . $dbi->driverName . '::QuantityDiscount';
    UsePackage($Package);
    GetLog->debug("call $Package->$FunctionName()");
    return $Package->$FunctionName( $dbi, @Parameter );
}

1;
