#========================================================================================
# package      DE_EPAGES::PriceList::DAL::SQL::GlobalValueDiscount
# state        public
# description  interface for table GlobalValueDiscount
#========================================================================================
package DE_EPAGES::PriceList::DAL::SQL::GlobalValueDiscount;

use strict;
use DE_EPAGES::Core::API::PerlTools qw (GetLoopFromDoubleArray);

#========================================================================================
# function     GetGlobalValueDiscounts
#----------------------------------------------------------------------------------------
# syntax       GetGlobalValueDiscounts($ShopID,$PriceListID);
#----------------------------------------------------------------------------------------
# description  Gets all the table entries for globalvaluediscount for a given ShopID and
# PriceListID.
#----------------------------------------------------------------------------------------
# input        $dbi | database handle | DE_EPAGES::Database::API::DBI
# input        $ShopID| shop id | int
# input        $PriceListID | pricelist id | int
# $return       $ahResult| with following keys:
#               <ul>
#                   <li>Value - value |                  - decimal
#                   <li>Discount - discount |            - double
#                   <li>DiscountAbsolute - discount absolute |        - decimal
#               </ul> | reference to array of hashes
#========================================================================================
sub GetGlobalValueDiscounts {
    my $self = shift;
    my ($dbi, $ShopID, $PriceListID ) = @_;
    my $dbResult = $dbi->execute( 'SELECT Value, Discount, DiscountAbsolute FROM globalvaluediscount AS gvd INNER JOIN pricelist as p ON gvd.pricelistid=p.pricelistid WHERE gvd.PriceListID=? AND p.shopid=? ORDER BY Value', [$PriceListID, $ShopID]);
    return GetLoopFromDoubleArray($dbResult, [ qw(Value Discount DiscountAbsolute) ]);
}
1;
