#========================================================================================
# package      DE_EPAGES::PriceList::DAL::SQL::QuantityDiscount
# state        public
# description  interface for table QuantityDiscount
#========================================================================================
package DE_EPAGES::PriceList::DAL::SQL::QuantityDiscount;

use strict;
use DE_EPAGES::Core::API::PerlTools qw (GetLoopFromDoubleArray);

#========================================================================================
# function     GetQuantityDiscounts
#----------------------------------------------------------------------------------------
# syntax       GetQuantityDiscounts($ShopID,$PriceListID);
#----------------------------------------------------------------------------------------
# description  Gets all the table entries for quantitydiscount for a given ShopID and
# PriceListID.
#----------------------------------------------------------------------------------------
# input        $dbi | database handle | DE_EPAGES::Database::API::DBI
# input        $ShopID| shop id | int
# input        $PriceListID | pricelist id | int
# $return       $ahResult| with following keys:
#               <ul>
#                   <li>ProductID - product id |         - int
#                   <li>Quantity - quantity |            - decimal
#                   <li>Discount - discount |            - double
#               </ul> | reference to array of hashes
#========================================================================================
sub GetQuantityDiscounts {
    my $self = shift;
    my ($dbi, $ShopID, $PriceListID ) = @_;
    my $dbResult = $dbi->execute( 'SELECT ProductID, Quantity, Discount FROM quantitydiscount AS qd INNER JOIN pricelist as p ON qd.pricelistid=p.pricelistid WHERE qd.PriceListID=? AND p.shopid=? ORDER BY Quantity ASC', [$PriceListID, $ShopID]);
    return GetLoopFromDoubleArray($dbResult, [ qw(ProductID Quantity Discount) ]);
}
1;
