#========================================================================================
# package      DE_EPAGES::PriceList::DAL::SQL::ScalePrice
# state        public
# description  interface for table ScalePrice
#========================================================================================
package DE_EPAGES::PriceList::DAL::SQL::ScalePrice;

use strict;
use DE_EPAGES::Core::API::PerlTools qw (GetLoopFromDoubleArray);

#========================================================================================
# function     DeleteScalePrices
#----------------------------------------------------------------------------------------
# syntax       DeleteScalePrices($PriceListID);
#----------------------------------------------------------------------------------------
# description  removes an all entries of table scale price with given price list id
#----------------------------------------------------------------------------------------
# input        $dbi | database handle | DE_EPAGES::Database::API::DBI
# input        $PriceListID | price list id | int
#========================================================================================
sub DeleteScalePrices {
    my $self = shift;
    my ( $dbi, $PriceListID ) = @_;
    $dbi->do( 'DELETE FROM scaleprice WHERE pricelistid=?', [$PriceListID] );
    return;
}

#========================================================================================
# function     GetScalePrices
#----------------------------------------------------------------------------------------
# syntax       GetScalePrices($ShopID,$PriceListID);
#----------------------------------------------------------------------------------------
# description  gets all the table entries for scale prices for a given ShopID and PriceListID.
#----------------------------------------------------------------------------------------
# input        $dbi | database handle | DE_EPAGES::Database::API::DBI
# input        $ShopID| shop id | int
# input        $PriceListID | pricelist id | int
# $return       $ahResult| with following keys:
#               <ul>
#                   <li>ProductID - product id |         - int
#                   <li>Quantity - quantity |            - decimal
#                   <li>Price - price |                  - decimal
#               </ul> | reference to array of hashes
#========================================================================================
sub GetScalePrices {
    my $self = shift;
    my ($dbi, $ShopID, $PriceListID ) = @_;
    my $dbResult = $dbi->execute( 'SELECT ProductID, Quantity, Price FROM scaleprice AS sp INNER JOIN pricelist as p ON sp.pricelistid=p.pricelistid WHERE sp.PriceListID=? AND p.shopid=?', [$PriceListID, $ShopID]);
    return GetLoopFromDoubleArray($dbResult, [ qw(ProductID Quantity Price) ]);
}
1;
