#========================================================================================
# package      DE_EPAGES::PriceList::DAL::ScalePrice
# state        public
# base         Exporter
# description  interface for table ScalePrice
#========================================================================================
package DE_EPAGES::PriceList::DAL::ScalePrice;
use base qw (Exporter);

use DE_EPAGES::Database::API::Connection qw (  GetCurrentDBHandle );
use DE_EPAGES::Core::API::Log qw ( GetLog );
use DE_EPAGES::Core::API::PerlTools qw ( UsePackage );

use strict;

our @EXPORT_OK = qw (
    DAL_DeleteScalePrices
    DAL_GetAllScalePricesByPriceListID
);

#========================================================================================
# function     DAL_DeleteScalePrices
#----------------------------------------------------------------------------------------
# syntax       DAL_DeleteScalePrices($PriceListID);
#----------------------------------------------------------------------------------------
# description  removes an all entries of table scale price with given price list id
#----------------------------------------------------------------------------------------
# input        $PriceListID | price list id | int
#========================================================================================
sub DAL_DeleteScalePrices {
    my ($PriceListID) = @_;

    _CallDriver( 'DeleteScalePrices', $PriceListID );

    return;
}

#========================================================================================
# function     DAL_GetAllScalePricesByPriceListID
#----------------------------------------------------------------------------------------
# syntax       DAL_GetAllScalePricesByPriceListID($ShopID, $PriceListID);
#----------------------------------------------------------------------------------------
# description  gets all the table entries for scale prices for a given shopID and pricelist ID.
#----------------------------------------------------------------------------------------
# input        $ShopID | shop id | int
# input        $PriceListID | pricelist id | int
# $return       $rahResult| with following keys:
#               <ul>
#                   <li>PriceListID   - pricelist id |   - int
#                   <li>ProductID - product id |         - int
#                   <li>Quantity - quantity |            - decimal
#                   <li>Price - price |                  - decimal
#               </ul> | reference to array of hashes
#========================================================================================
sub DAL_GetAllScalePricesByPriceListID {
    my ($ShopID, $PriceListID) = @_;

    return _CallDriver('GetScalePrices', $ShopID, $PriceListID);
}

sub _CallDriver {
    my ( $FunctionName, @Parameter ) = @_;
    my $dbi     = GetCurrentDBHandle();
    my $Package = 'DE_EPAGES::PriceList::DAL::' . $dbi->driverName . '::ScalePrice';
    UsePackage($Package);
    GetLog->debug("call $Package->$FunctionName()");
    return $Package->$FunctionName( $dbi, @Parameter );
}

1;
