#==============================================================================
# package      DE_EPAGES::Product::UI::LineItemContainer
# state        private
#==============================================================================
package DE_EPAGES::Product::UI::LineItemContainer;
use base DE_EPAGES::Presentation::UI::Object;

use strict;
use DE_EPAGES::Core::API::Error qw( ExistsError GetError Error );
use DE_EPAGES::Core::API::PerlTools qw( ElementOf );
use DE_EPAGES::Product::API::LineItemContainer qw( UpdateLineItem );
use DE_EPAGES::Product::API::Shop qw(GetProduct);


sub AddProductLineItem {
    my $self = shift;
    my ($Servlet) = @_;
    my $LineItemContainer = $Servlet->object;
    my $Shop = $LineItemContainer->getSite();

    my $NewSKU = $Servlet->params('NewSKU');
    my $NewQuantity = $Servlet->params('NewQuantity');

    return $LineItemContainer->parent unless $NewSKU =~/\S/;

    # test if Product exists and add product
    my $Product = GetProduct($Shop, $NewSKU);
    if (not defined $Product) {
        $Servlet->params('SKUNotExists',1) ;
        return $LineItemContainer->parent;
    }
    my $DefaultSubProduct = $Product->get('DefaultSubProduct');
    $Product = $DefaultSubProduct if defined $DefaultSubProduct;

    eval {
        my $LineItem = $Product->addToContainer($LineItemContainer, {'Quantity'=>$NewQuantity, 'IsEditOrder'=>1});
        UpdateLineItem($LineItem, $LineItemContainer);
    };
    if (ExistsError()) {
        my $Error = GetError();
        if (ElementOf($Error->code, qw (ProductNoPrice ProductCanNotAddToBasket ProductCanNotChangedAtBasket))) {
            $Servlet->form->mapFormError({'Name'  => 'AddToBasket'}, $Error);
            $Servlet->form->executeFormError;
        } else {
            Error($Error);
        }
        return $LineItemContainer->parent;
    }

    $LineItemContainer->recalculate;

    $Servlet->params('UpdateNotApplied',1);
    return $LineItemContainer->parent;
}

sub AddProductLineItemsFromTray {
    my $self = shift;
    my ($Servlet) = @_;
    my $LineItemContainer = $Servlet->object;
    my $Tray = DE_EPAGES::Presentation::API::Object::Tray->load($Servlet->intSessionID);

    #get only elements by ProductClass
    my $GroupObjects = $Tray->objectsByClass('Product');
    foreach my $GroupObject (@{$GroupObjects}){
        eval {
            #--- if there is a super product in the tray add default sub product
            my $DefaultSubProduct = $GroupObject->get('DefaultSubProduct');
            my $LineItem;
            if (defined $DefaultSubProduct) {
                $LineItem = $DefaultSubProduct->addToContainer($LineItemContainer, {'Quantity'=>1, 'IsEditOrder'=>1});

            } else {
                $LineItem = $GroupObject->addToContainer($LineItemContainer, {'Quantity'=>1,'IsEditOrder'=>1});
            }
            UpdateLineItem($LineItem, $LineItemContainer);
        };
        if (ExistsError()) {
            my $Error = GetError();
            if (ElementOf($Error->code, qw (ProductNoPrice ProductCanNotAddToBasket ProductCanNotChangedAtBasket))) {
                $Servlet->form->mapFormError({'Name'  => 'AddToBasket'}, $Error);
                $Servlet->form->executeFormError;
            } else {
                Error($Error);
            }
        }
        $LineItemContainer->recalculate;
    }
    $Servlet->params('UpdateNotApplied',1);
    return $LineItemContainer->parent;
}

1;


