#========================================================================================
# package      DE_EPAGES::ShippingTypes::UI::ShippingMethodSingleLevel
# state        private
#----------------------------------------------------------------------------------------
# description  User interface for ShippingMethodFixPrice and ShippingMethodFreeLimit.
#========================================================================================
package DE_EPAGES::ShippingTypes::UI::ShippingMethodSingleLevel;
use base DE_EPAGES::Shipping::UI::ShippingMethod;

use strict;
use DE_EPAGES::Object::API::Table::Currency qw( GetInfoCurrency );
use DE_EPAGES::Tax::API::Shop qw ( ShouldSplitShippingAndPaymentTax );


sub UnityViewSettings {
    my $self = shift;
    my ($Servlet) = @_;

    my $Shop = $Servlet->object->getSite();
    my $SplitShippingTaxes = ShouldSplitShippingAndPaymentTax($Shop)->[0];

    # Only display tax class selection on settings page in case it is not splitted (UNITY-4811)
    $Servlet->vars('DisplayTaxClass', $SplitShippingTaxes ? 0 : 1);

    $self->View($Servlet);
}

sub View {
    my $self = shift;
    my $Servlet = shift;

    $self->SUPER::View($Servlet);

    my $ShippingMethod = $Servlet->object;
    my $Shop = $ShippingMethod->getSite();
    my $InputTaxModel = $Shop->get('InputTaxModel');

    # collect shipping levels, add empty rows for new currencies
    my @Levels;
    foreach my $CurrencyID (@{$Shop->currencies}) {
        my $ahLevels = $ShippingMethod->getLevels($CurrencyID, $InputTaxModel, {'ExtraPrecision' => 1});
        # copy the data, there should be only one level
        my $hLevel = (scalar @$ahLevels > 0) ? $ahLevels->[0] : {};
        my $hCurrency = GetInfoCurrency($CurrencyID);
        push @Levels, { %$hLevel, %$hCurrency };
    }

    $Servlet->params('ShippingLevels', \@Levels);
    return;
}

sub Save {
    my $self = shift;
    my $Servlet = shift;

    my $ShippingMethod = $Servlet->object;
    my $Shop = $ShippingMethod->getSite();
    my $InputTaxModel = $Shop->get('InputTaxModel');

    # set tax class before prices
    $self->SUPER::Save($Servlet);

    # save shipping levels after save tax class
    my $Form = $Servlet->form->form($ShippingMethod, 'SaveSingleLevel');
    foreach my $hLevel (@{$Form->{'ShippingLevels'}}) {
        # there should be only one level per currency
        my $CurrencyID = $hLevel->{'CurrencyID'};
        my $ahLevels = [];
        if( defined $hLevel->{'BaseValue'} ) {
            delete $hLevel->{'CurrencyID'};
            $ahLevels = [$hLevel];
        }

        $ShippingMethod->setLevels($CurrencyID, $InputTaxModel, $ahLevels);
    }

    # set shipping method invisible if shiping is incomplete
    my $IsActivated = $ShippingMethod->get('IsActivated');
    if ($IsActivated == 1) {
        my $aShopCurrencies = $Shop->get('Currencies');
        my @ActiveCurrencies = grep { $_->{'IsActivated'} == 1 } @$aShopCurrencies;
        my $hVars = { 'TaxModel'   => $Shop->get('TaxModel') };
        foreach my $ActiveCurrency (@ActiveCurrencies) {
            $hVars->{'CurrencyID'} = $ActiveCurrency->{'CurrencyID'};
            my $SettingsComplete = $ShippingMethod->usableAtStorefront($hVars);
            if ($SettingsComplete == 0) {
                $ShippingMethod->set({'IsActivated' => 0});
                $Servlet->vars('SetInvisible', 1);
            }
        }
    }

    # set ContainerSubTotalAttrName to LineItemsSubTotal if there is no selection box
    if (not defined $ShippingMethod->get('ContainerSubTotalAttrName') and $ShippingMethod->get('ShippingType')->get('Alias') eq 'ExemptionLimit') {
        $ShippingMethod->set({'ContainerSubTotalAttrName' => 'LineItemsSubTotal'});
    }

    return;
}

1;
