#========================================================================================
# package      DE_EPAGES::ShopMigration::API::JSONLines::CustomerGroupsExportImport;
# state        public
#----------------------------------------------------------------------------------------
# description  Some helper functions to export / import customergroup objects.
#========================================================================================
package DE_EPAGES::ShopMigration::API::JSONLines::CustomerGroupsExportImport;
use base qw(DE_EPAGES::ShopMigration::API::JSONLines::ShopObjectExportImport Exporter);

use strict;
use DE_EPAGES::Core::API::TestParameter qw(TestObject TestString);

our @EXPORT_OK = qw(
    ExportCustomerGroupsJSON
    ImportCustomerGroupsJSON
);

#========================================================================================
# function     ExportCustomerGroupsJSON
# state        public
#----------------------------------------------------------------------------------------
# syntax       ExportCustomerGroupsJSON($Shop, $DirName)
#----------------------------------------------------------------------------------------
# description  Exports customergroups data to a json file
#----------------------------------------------------------------------------------------
# input        $Shop | shop object | object
# input        $DirName | export directory | string
# return       $Exporter |  exporter | object
#========================================================================================
sub ExportCustomerGroupsJSON {
    my ($Shop, $DirName) = @_;
    TestObject('Shop', $Shop);
    TestString('DirName', $DirName);

    my $CustomerGroupsHandler = __PACKAGE__->new($Shop);
    return $CustomerGroupsHandler->exportJSONData($DirName, $CustomerGroupsHandler->getExportItems());
}

#========================================================================================
# function     ImportCustomerGroupsJSON
# state        public
#----------------------------------------------------------------------------------------
# syntax       ImportCustomerGroupsJSON($Shop, $DirName)
#----------------------------------------------------------------------------------------
# description  Imports customerGroup data from a json file
#----------------------------------------------------------------------------------------
# input        $Shop | shop object | object
# input        $DirName | export directory | string
# return       $Importer |  importer | object
#========================================================================================
sub ImportCustomerGroupsJSON {
    my ($Shop, $DirName) = @_;
    TestObject('Shop', $Shop);
    TestString('DirName', $DirName);

    my $CustomerGroupsHandler = __PACKAGE__->new($Shop);
    return $CustomerGroupsHandler->importJSONData($DirName);
}

sub getExportItems {
    my $self = shift;
    return $self->shop()->get('CustomerGroups');
}

sub importDriver {
    my $self = shift;
    return 'DE_EPAGES::ShopMigration::API::JSONLines::CustomerGroupsImportHandler';
}

sub exportDriver {
    my $self = shift;
    return 'DE_EPAGES::ShopMigration::API::JSONLines::CustomerGroupsExportDriver';
}

1;
