#========================================================================================
# package      DE_EPAGES::ShopMigration::API::JSONLines::PriceListScalePricesExportImport;
# state        public
#----------------------------------------------------------------------------------------
# description  Some helper functions to export / import scale prices.
#========================================================================================
package DE_EPAGES::ShopMigration::API::JSONLines::PriceListScalePricesExportImport;
use base qw(DE_EPAGES::ShopMigration::API::JSONLines::ShopObjectExportImport Exporter);

use strict;
use DE_EPAGES::Core::API::TestParameter qw(TestObject TestString);
use DE_EPAGES::ShopMigration::API::PriceListScalePricesCommon qw ( 
    GetPriceListScalePrices
 );
our @EXPORT_OK = qw(
    ExportPriceListScalePricesJSON
    ImportPriceListScalePricesJSON
);


#========================================================================================
# function     ExportPriceListScalePricesJSON
# state        public
#----------------------------------------------------------------------------------------
# syntax       ExportPriceListScalePricesJSON($Shop, $DirName)
#----------------------------------------------------------------------------------------
# description  Exports scale price data to a json file
#----------------------------------------------------------------------------------------
# input        $Shop | shop object | object
# input        $DirName | export directory | string
# return       $Exporter |  exporter | object
#========================================================================================
sub ExportPriceListScalePricesJSON {
    my ($Shop, $DirName) = @_;
    TestObject('Shop', $Shop);
    TestString('DirName', $DirName);

    my $PriceListScalePricesHandler = __PACKAGE__->new($Shop);
    return $PriceListScalePricesHandler->exportJSONData($DirName, $PriceListScalePricesHandler->getExportItems());
}

#========================================================================================
# function     ImportPriceListScalePricesJSON
# state        public
#----------------------------------------------------------------------------------------
# syntax       ImportPriceListScalePricesJSON($Shop, $DirName)
#----------------------------------------------------------------------------------------
# description  Imports scale price  data from a json file
#----------------------------------------------------------------------------------------
# input        $Shop | shop object | object
# input        $DirName | export directory | string
# return       $Importer |  importer | object
#========================================================================================
sub ImportPriceListScalePricesJSON {
    my ($Shop, $DirName) = @_;
    TestObject('Shop', $Shop);
    TestString('DirName', $DirName);

    my $PriceListScalePricesHandler = __PACKAGE__->new($Shop);
    return $PriceListScalePricesHandler->importJSONData($DirName);
}

sub getExportItems {
    my $self = shift;
    my $Shop = $self->shop();
    my $PriceListScalePrices = GetPriceListScalePrices($Shop);
    return $PriceListScalePrices;

}

sub importDriver {
    my $self = shift;
    return 'DE_EPAGES::ShopMigration::API::JSONLines::PriceListScalePricesImportHandler';
}

sub exportDriver {
    my $self = shift;
    return 'DE_EPAGES::ShopMigration::API::JSONLines::PriceListScalePricesExportDriver';
}

1;
