#========================================================================================
# package      DE_EPAGES::ShopMigration::API::JSONLines::PriceListsExportImport;
# state        public
#----------------------------------------------------------------------------------------
# description  Some helper functions to export / import pricelist objects.
#========================================================================================
package DE_EPAGES::ShopMigration::API::JSONLines::PriceListsExportImport;
use base qw(DE_EPAGES::ShopMigration::API::JSONLines::ShopObjectExportImport Exporter);

use strict;
use DE_EPAGES::Core::API::TestParameter qw(TestObject TestString);
our @EXPORT_OK = qw(
    ExportPriceListsJSON
    ImportPriceListsJSON
);
use DE_EPAGES::PriceList::API::PriceList qw (GetExportablePriceLists);

#========================================================================================
# function     ExportPriceListsJSON
# state        public
#----------------------------------------------------------------------------------------
# syntax       ExportPriceListsJSON($Shop, $DirName)
#----------------------------------------------------------------------------------------
# description  Exports pricelists data to a json file
#----------------------------------------------------------------------------------------
# input        $Shop | shop object | object
# input        $DirName | export directory | string
# return       $Exporter |  exporter | object
#========================================================================================
sub ExportPriceListsJSON {
    my ($Shop, $DirName) = @_;
    TestObject('Shop', $Shop);
    TestString('DirName', $DirName);

    my $PriceListsHandler = __PACKAGE__->new($Shop);
    return $PriceListsHandler->exportJSONData($DirName, $PriceListsHandler->getExportItems());
}

#========================================================================================
# function     ImportPriceListsJSON
# state        public
#----------------------------------------------------------------------------------------
# syntax       ImportPriceListsJSON($Shop, $DirName)
#----------------------------------------------------------------------------------------
# description  Imports pricelist data from a json file
#----------------------------------------------------------------------------------------
# input        $Shop | shop object | object
# input        $DirName | export directory | string
# return       $Importer |  importer | object
#========================================================================================
sub ImportPriceListsJSON {
    my ($Shop, $DirName) = @_;
    TestObject('Shop', $Shop);
    TestString('DirName', $DirName);

    my $PriceListsHandler = __PACKAGE__->new($Shop);
    return $PriceListsHandler->importJSONData($DirName);
}

sub getExportItems {
    my $self = shift;

    my $Shop = $self->shop();
    return GetExportablePriceLists($Shop);

}

sub importDriver {
    my $self = shift;
    return 'DE_EPAGES::ShopMigration::API::JSONLines::PriceListsImportHandler';
}

sub exportDriver {
    my $self = shift;
    return 'DE_EPAGES::ShopMigration::API::JSONLines::PriceListsExportDriver';
}

1;
