#========================================================================================
# package      DE_EPAGES::Zettle::API::Attributes::ZettleEnvironment
# state        private
# base         DE_EPAGES::Object::API::BaseAttribute
# description  Implements the ZettleEnvironment attributes
#========================================================================================
package DE_EPAGES::Zettle::API::Attributes::ZettleEnvironment;
use base qw( DE_EPAGES::Object::API::BaseAttribute );

use strict;

#========================================================================================
# function     getAttributes
# state        private
# syntax       $Value = $Object->get($AttributeName);
#========================================================================================
sub getAttributes {
    shift;
    my ($Object, $aNames) = @_;

    my %Values;
    foreach my $Name (@$aNames) {
        if ( $Name eq 'LastStockSync' ) {
            $Values{$Name} = _LastStockSync($Object);
        }
    }
    return \%Values;
}

#========================================================================================
# function     _LastStockSync
# state        public
#----------------------------------------------------------------------------------------
# syntax       $LastStockSync = $self->_LastStockSync();
#----------------------------------------------------------------------------------------
# description  Returns the more recent date from ProductStockLevelUpdateTimeZettle and ProductStockLevelUpdateTime.
#----------------------------------------------------------------------------------------
# return       $LastStockSync | DateTime of last stock update | DateTime
#========================================================================================
sub _LastStockSync {
    my ($Object) = @_;

    my $ProductStockLevelUpdateTimeZettle = $Object->get('ProductStockLevelUpdateTimeZettle');
    my $ProductStockLevelUpdateTime = $Object->get('ProductStockLevelUpdateTime');

    return $ProductStockLevelUpdateTime unless defined $ProductStockLevelUpdateTimeZettle;

    return $ProductStockLevelUpdateTimeZettle unless defined $ProductStockLevelUpdateTimeZettle;

    return ($ProductStockLevelUpdateTimeZettle > $ProductStockLevelUpdateTime)
            ? $ProductStockLevelUpdateTimeZettle
            : $ProductStockLevelUpdateTime;
}

1;
