#========================================================================================
# package      DE_EPAGES::Zettle::API::Logger
# state        public
#----------------------------------------------------------------------------------------
# description  Wrapper of LogContext DE_EPAGES::Zettle::API::Logger
#========================================================================================
package DE_EPAGES::Zettle::API::Logger;

use strict;

use Scalar::Util qw (blessed);

use DE_EPAGES::Core::API::Log qw ( LogCommunication );
use DE_EPAGES::Object::API::Factory qw (LoadRootObject);
use DE_EPAGES::Zettle::API::Constants qw( INTERNAL_CARTRIDGE_NAME );

#========================================================================================
# function     new
# state        public
#----------------------------------------------------------------------------------------
# syntax       DE_EPAGES::Zettle::API::Logger->new();
#----------------------------------------------------------------------------------------
# description  constructor
#----------------------------------------------------------------------------------------
# return       $self | self | DE_EPAGES::Zettle::API::Logger
#========================================================================================
sub new {
    my $class = shift;
    my $self  = bless {}, $class;
    return $self;
}

#========================================================================================
# function     logCommunication
# state        public
#----------------------------------------------------------------------------------------
# syntax       $self->logCommunication( $Name, $Structure);
#----------------------------------------------------------------------------------------
# description  Dumps the data structure $Structure to the log file if logging is activated.
#               See <function DE_EPAGES::Core::API::Log::LogCommunication>.
#----------------------------------------------------------------------------------------
# input        $Name | name of data structure for identification in the log file | string
# input        $Structure | the object | scalar (usually hash or array ref)
#========================================================================================
sub logCommunication {
    my $self = shift;
    my ($Name, $Structure) = @_;
    
    if($self->_isLoggingActivated()){
        my $Category = INTERNAL_CARTRIDGE_NAME;
        my $Filter = sub {
            my $LogString = shift;
            # filter client_secret
            $$LogString =~s/(?<='client_secret' => ')[^']*?(?=')/---replaced---/g;
            $$LogString =~s/(?<=client_secret=)[-a-zA-Z0-9]*?(?=(&|$))/---replaced---/g;
            # filter refresh_token
            $$LogString =~s/(?<='refresh_token' => ')[^']*?(?=')/---replaced---/g;
            $$LogString =~s/(?<=refresh_token=)[-a-zA-Z0-9]*?(?=(&|$))/---replaced---/g;
            $$LogString =~s/(?<="refresh_token":")[^"]*?(?=")/---replaced---/g;
        };
        my $CallerDepth = 2;
        $self->_LogCommunication($Name, $Structure, $Category, $Filter, $CallerDepth);
    }
    return;
}


#========================================================================================


#========================================================================================
sub _LogCommunication {
    my $self = shift;
    my ($Name, $Structure, $Category, $aFilter, $CallerDepth) = @_;
    my $Prettify = $self->_prettify($Structure);
    LogCommunication($Name, $Prettify, $Category, $aFilter, $CallerDepth);
    return;
}

#========================================================================================
sub _isLoggingActivated {
    my $self = shift;
    return LoadRootObject()->get('Zettle_Logging');
}

#========================================================================================
sub _prettify {
    my $self = shift;
    my ($Structure) = @_;
    my $NameOfClass = blessed($Structure);
    return $Structure unless defined $NameOfClass;

    if($NameOfClass eq 'HTTP::Response') {
        return $self->_prettyResponse($Structure);
    }
    return $Structure;
}

#========================================================================================
sub _prettyResponse {
    my $self = shift;
    my ($Response) = @_;
    return sprintf ("\n Request: %s \n Response: %s \n", $Response->request()->as_string(), $Response->as_string());
}

1;