#========================================================================================
# package      DE_EPAGES::Zettle::API::WebService::DTO::ProductDTO
# state        public
#----------------------------------------------------------------------------------------
# description  class to prepare the product data for requests
#========================================================================================
package DE_EPAGES::Zettle::API::WebService::DTO::ProductDTO;

use strict;

use DE_EPAGES::Zettle::API::Constants qw ( API_PARTNER_ID );
use DE_EPAGES::Zettle::API::WebService::DTO::Requirements qw ( AdjustProductName AdjustProductDescription );

#========================================================================================
# function     new
# state        public
#----------------------------------------------------------------------------------------
# syntax       new( );
#----------------------------------------------------------------------------------------
# description  constructor
#----------------------------------------------------------------------------------------
# return       $self | self | DE_EPAGES::Zettle::API::WebService::DTO::ProductDTO
#========================================================================================
sub new {
    my $class = shift;
    my $self  = bless {}, $class;
    return $self;
}

# input        $Uuid | Product UUIDv1 | string
sub uuid {
    my $self = shift;
    my ($Uuid) = @_;
    return $self->{'uuid'} unless (defined($Uuid));
    $self->{'uuid'} = $Uuid;
}

# input        $Category | Product main category name | string
sub categories {
    my $self = shift;
    my ($Categories) = @_;
    return $self->{'categories'} unless (defined($Categories));
    $self->{'categories'} = $Categories;
}

# input        $Name | Product name | string
sub name {
    my $self = shift;
    my ($Name) = @_;
    return $self->{'name'} unless (defined($Name));
    $self->{'name'} = $Name;
}

# input        $Description | Product description | string
sub description {
    my $self = shift;
    my ($Description) = @_;
    return $self->{'description'} unless (defined($Description));
    $self->{'description'} = $Description;
}

# input        $ImageLookupKeys | Product image Zettle lookup keys <function DE_EPAGES::Zettle::API::WebService::ImageService::uploadImage> | ref.array.string
sub imageLookupKeys {
    my $self = shift;
    my ($ImageLookupKeys) = @_;
    return $self->{'imageLookupKeys'} unless (defined($ImageLookupKeys));
    $self->{'imageLookupKeys'} = $ImageLookupKeys;
}

#TODO: determine whether 'presentation' field will ever be exported from ePages and discard it otherwise
sub presentation {
    #imageUrl
    #backgroundColor
    #textColor
}

# input        $aVariationDTOs | Product variants | ref.array.DE_EPAGES::Zettle::API::WebService::DTO::VariantDTO
sub variations {
    my $self = shift;
    my ($aVariationDTOs) = @_;
    return $self->{'variations'} unless (defined($aVariationDTOs));
    $self->{'variations'} = $aVariationDTOs;
}

# input        $ExternalReference | Product ID | string
sub externalReference {
    my $self = shift;
    my ($ExternalReference) = @_;
    return $self->{'externalReference'} unless (defined($ExternalReference));
    $self->{'externalReference'} = $ExternalReference;
}

# input        $UnitName | Product selling unit (e.g. Kg) | string
sub unitName {
    my $self = shift;
    my ($UnitName) = @_;
    return $self->{'unitName'} unless (defined($UnitName));
    $self->{'unitName'} = $UnitName;
}

# input        $VatPercentage | Variation VAT percentage (0-100) | integer
sub vatPercentage {
    my $self = shift;
    my ($VatPercentage) = @_;
    return $self->{'vatPercentage'} unless (defined($VatPercentage));
    $self->{'vatPercentage'} = $VatPercentage;
}

#TODO: determine whether 'online' field will ever be exported from ePages and discard it otherwise
sub online {
    #status
    #title
    #description
    #shipping: shippingPricingModel, weightInGrams, weight
    #presentation: displayImageUrl, additionalImageUrls, mediaUrls
    #seo: title, metaDescription, slug
}

# input        $ahOptions | Product variant option definitions | ref.array.hash
sub variantOptionDefinitions {
    my $self = shift;
    my ($ahOptions) = @_;
    return $self->{'variantOptionDefinitions'} unless (defined($ahOptions));
    $self->{'variantOptionDefinitions'} = $ahOptions;
}

# input        $TaxCode | Product tax code | string
sub taxCode {
    my $self = shift;
    my ($TaxCode) = @_;
    return $self->{'taxCode'} unless (defined($TaxCode));
    $self->{'taxCode'} = $TaxCode;
}

#TODO: check what should its contents be and what's the difference with 'categories'
sub category {
}

# input        $hOptions | Product metadata | ref.hash
sub metadata {
    my $self = shift;
    my ($hOptions) = @_;
    return $self->{'metadata'} unless (defined($hOptions));
    $self->{'metadata'} = $hOptions;
}

#TODO: check what values should be filled in here and what's the relation with vatPercentage
# input        $TaxRates | Product tax code | string
sub taxRates {
    my $self = shift;
    my ($TaxRates) = @_;
    return $self->{'taxRates'} unless (defined($TaxRates));
    $self->{'taxRates'} = $TaxRates;
}

#TODO: is this related to Shop TaxModel (gross/net)?
sub taxExempt {
}

#========================================================================================
# function     parseDTO
# state        public
#----------------------------------------------------------------------------------------
# syntax       parseDTO();
#----------------------------------------------------------------------------------------
# description  parse product DTO to extract a Product object
#----------------------------------------------------------------------------------------
# return       $Product | a product | DE_EPAGES::Product::API::Object::Product
#========================================================================================
sub parseDTO {
    #TODO: parseDTO
}

sub toHash {
    my $self     = shift;

    my $hContent = {
        'uuid' => $self->uuid(),
        'name' => AdjustProductName($self->name()),
    };

    #TODO: review if there is an alternative to avoid using all the if clauses that follow
    $hContent->{'categories'} = $self->categories() if defined $self->categories();
    $hContent->{'description'} = AdjustProductDescription($self->description()) if defined $self->description();
    $hContent->{'imageLookupKeys'} = $self->imageLookupKeys() if defined $self->imageLookupKeys();
    $hContent->{'presentation'} = $self->presentation() if defined $self->presentation();
    $hContent->{'variants'} = _toZettleVariations($self->variations()) if defined $self->variations();
    $hContent->{'externalReference'} = $self->externalReference() if defined $self->externalReference();
    $hContent->{'unitName'} = $self->unitName() if defined $self->unitName();
    $hContent->{'vatPercentage'} = $self->vatPercentage() if defined $self->vatPercentage();
    # $hContent->{'online'} = $self->online() if $self->online();
    $hContent->{'variantOptionDefinitions'} = {
        "definitions" => $self->variantOptionDefinitions()
     } if defined $self->variantOptionDefinitions();
    $hContent->{'taxCode'} = $self->taxCode() if defined $self->taxCode(); #TODO: check what value should be filled in here
    $hContent->{'category'} = $self->category() if defined $self->category(); #TODO: check what should its contents be and what's the difference with 'categories'
    $hContent->{'metadata'} = {
                                'inPos' => 'true',
                                'source' => {
                                    'name' => API_PARTNER_ID, # epages
                                    'external' => 'true',
                                }
                              };
    $hContent->{'taxRates'} = $self->taxRates() if defined $self->taxRates(); #TODO: check what values should be filled in here and what's the relation with vatPercentage
    $hContent->{'taxExempt'} = $self->taxExempt() if defined $self->taxExempt(); #TODO: is this related to Shop TaxModel (gross/net)?
    
    return $hContent;
}

# input        $aVariationDTOs | Product variation DTOs | ref.array.DE_EPAGES::Zettle::API::WebService::DTO::VariantDTO
# return        $ahVariations | Array of product variations as expected by Zettle API | ref.array.hash
sub _toZettleVariations {
    my ($aVariationDTOs) = @_;

    my @ZettleVariations = ();
    foreach my $VariationDTO (@{$aVariationDTOs}) {
        push (@ZettleVariations, $VariationDTO->toHash());
    }

    return \@ZettleVariations;
}

1;