#========================================================================================
# package      DE_EPAGES::Zettle::API::WebService::DTO::ProductResponseDTO
# state        public
#----------------------------------------------------------------------------------------
# description  wrapper for product response data
#========================================================================================
package DE_EPAGES::Zettle::API::WebService::DTO::ProductResponseDTO;
use base DE_EPAGES::Zettle::API::WebService::DTO::ProductDTO;

use strict;

use JSON;


#========================================================================================
# function     new
# state        public
#----------------------------------------------------------------------------------------
# syntax       new( );
#----------------------------------------------------------------------------------------
# description  constructor
#----------------------------------------------------------------------------------------
# return       $self | self | DE_EPAGES::Zettle::API::WebService::DTO::ProductResponseDTO
#========================================================================================
sub new {
    my $class = shift;

    my $self = $class->SUPER::new();

    return $self;
}

# input        $Etag | Product ETAG | string
sub etag {
    my $self = shift;
    my ($Etag) = @_;
    return $self->{'etag'} unless (defined($Etag));
    $self->{'etag'} = $Etag;
}

# input        $Updated | Product last update | Datetime
sub updated {
    my $self = shift;
    my ($Updated) = @_;
    return $self->{'updated'} unless (defined($Updated));
    $self->{'updated'} = $Updated;
}

# input        $UpdatedBy | UUID of user who last updated the product | string
sub updatedBy {
    my $self = shift;
    my ($UpdatedBy) = @_;
    return $self->{'updatedBy'} unless (defined($UpdatedBy));
    $self->{'updatedBy'} = $UpdatedBy;
}

# input        $Created | Product creation date | Datetime
sub created {
    my $self = shift;
    my ($Created) = @_;
    return $self->{'created'} unless (defined($Created));
    $self->{'created'} = $Created;
}

#========================================================================================
# function     parseResponse
# state        public
#----------------------------------------------------------------------------------------
# syntax       $ProductResponseDTO = DE_EPAGES::Zettle::API::WebService::DTO::ProductResponseDTO->parseResponse($ProductResponse);
#----------------------------------------------------------------------------------------
# description  parse JSON contents from API product response to produce a ProductResponseDTO object
#----------------------------------------------------------------------------------------
# input        $ProductResponse | JSON structure retrieved from API product query.
#                              See Responses > Schema > ProductResponse in https://products.izettle.com/swagger#/products/getAllProductsV2 | string
#----------------------------------------------------------------------------------------
# return        $ProductResponseDTO | a product response object | DE_EPAGES::Zettle::API::WebService::DTO::ProductResponseDTO
#========================================================================================
sub parseResponse {
    my $class = shift;
    my ($ProductResponse) = @_;

    my $ProductResponseDTO = $class->new();
    $ProductResponseDTO->uuid($ProductResponse->{'uuid'});
    $ProductResponseDTO->categories($ProductResponse->{'categories'});
    $ProductResponseDTO->description($ProductResponse->{'description'});
    $ProductResponseDTO->presentation($ProductResponse->{'presentation'});
    $ProductResponseDTO->variations($ProductResponse->{'variants'});
    $ProductResponseDTO->externalReference($ProductResponse->{'externalReference'});
    $ProductResponseDTO->etag($ProductResponse->{'etag'});
    $ProductResponseDTO->updated($ProductResponse->{'updated'});
    $ProductResponseDTO->updatedBy($ProductResponse->{'updatedBy'});
    $ProductResponseDTO->created($ProductResponse->{'created'});
    $ProductResponseDTO->unitName($ProductResponse->{'unitName'});
    $ProductResponseDTO->vatPercentage($ProductResponse->{'vatPercentage'});
    $ProductResponseDTO->online($ProductResponse->{'online'});
    $ProductResponseDTO->variantOptionDefinitions($ProductResponse->{'variantOptionDefinitions'});
    $ProductResponseDTO->taxCode($ProductResponse->{'taxCode'});
    $ProductResponseDTO->category($ProductResponse->{'category'});
    $ProductResponseDTO->metadata($ProductResponse->{'metadata'});
    $ProductResponseDTO->taxRates($ProductResponse->{'taxRates'}[0]);
    $ProductResponseDTO->taxExempt($ProductResponse->{'taxExempt'});

    return $ProductResponseDTO;
}


#========================================================================================


1;
