#========================================================================================
# package      DE_EPAGES::Zettle::API::WebService::DTO::VariationDTO
# state        public
#----------------------------------------------------------------------------------------
# description  class to prepare the variation data for requests
#========================================================================================
package DE_EPAGES::Zettle::API::WebService::DTO::VariationDTO;

use strict;

use DE_EPAGES::Zettle::API::WebService::DTO::Requirements qw ( AdjustProductName AdjustProductDescription );

#========================================================================================
# function     new
# state        public
#----------------------------------------------------------------------------------------
# syntax       new( );
#----------------------------------------------------------------------------------------
# description  constructor
#----------------------------------------------------------------------------------------
# return       $self | self | DE_EPAGES::Zettle::API::WebService::DTO::VariationDTO
#========================================================================================
sub new {
    my $class = shift;
    my $self  = bless {}, $class;
    return $self;
}

# input        $Uuid | Variation UUIDv1. Required | string
sub uuid {
    my $self = shift;
    my ($Uuid) = @_;
    return $self->{'uuid'} unless (defined($Uuid));
    $self->{'uuid'} = $Uuid;
}

# input        $Name | Variation name | string
sub name {
    my $self = shift;
    my ($Name) = @_;
    return $self->{'name'} unless (defined($Name));
    $self->{'name'} = $Name;
}

# input        $Description | Variation description | string
sub description {
    my $self = shift;
    my ($Description) = @_;
    return $self->{'description'} unless (defined($Description));
    $self->{'description'} = $Description;
}

# input        $Sku | Variation SKU | string
sub sku {
    my $self = shift;
    my ($Sku) = @_;
    return $self->{'sku'} unless (defined($Sku));
    $self->{'sku'} = $Sku;
}

# input        $Barcode | Variation barcode | string
sub barcode {
    my $self = shift;
    my ($Barcode) = @_;
    return $self->{'barcode'} unless (defined($Barcode));
    $self->{'barcode'} = $Barcode;
}

# input        $Price | Variation price. Required | float
sub price {
    my $self = shift;
    my ($Price) = @_;
    return $self->{'price'} unless (defined($Price));
    $self->{'price'} = $Price;
}

# input        $CostPrice | Variation cost price. Required | float
sub costPrice {
    my $self = shift;
    my ($CostPrice) = @_;
    return $self->{'costPrice'} unless (defined($CostPrice));
    $self->{'costPrice'} = $CostPrice;
}

# input        $CurrencyCode | Variation price currency code (ISO 4217: https://publications.europa.eu/code/en/en-5000700.htm) | char(3)
sub currencyCode {
    my $self = shift;
    my ($CurrencyCode) = @_;
    return $self->{'currencyCode'} unless (defined($CurrencyCode));
    $self->{'currencyCode'} = $CurrencyCode;
}

# input        $VatPercentage | Variation VAT percentage (0-100) | integer
sub vatPercentage {
    my $self = shift;
    my ($VatPercentage) = @_;
    return $self->{'vatPercentage'} unless (defined($VatPercentage));
    $self->{'vatPercentage'} = $VatPercentage;
}

# input        $Options | Variation options | ref.array.hash
sub options {
    my $self = shift;
    my ($Options) = @_;
    return $self->{'options'} unless (defined($Options));
    $self->{'options'} = $Options;
}

#TODO: determine whether 'presentation' field will ever be exported from ePages and discard it otherwise
sub presentation {
    #imageUrl
    #backgroundColor
    #textColor
}

sub toHash {
    my $self     = shift;

    # Fill in required fields. See https://products.izettle.com/swagger#/import/importLibraryV2 (Request Body > Schema)
    my $hContent = {
        'uuid' => $self->uuid(),
    };
    $hContent->{'name'} = AdjustProductName($self->name()) if $self->name();
    $hContent->{'description'} = AdjustProductDescription($self->description()) if $self->description();
    $hContent->{'sku'} = $self->sku() if $self->sku();
    $hContent->{'barcode'} = $self->barcode() if $self->barcode();
    $hContent->{'price'} = {
            # Force numeric context with "+0.0", otherwise Zettle WS returns an error because it receives a string when a numeric value is expected
            # Example: 400 Bad Request - Cannot deserialize value of type `long` from String "88.6": not a valid `long` value
            'amount' => $self->price()+0.0,
            'currencyId' => $self->currencyCode,
    } if defined $self->price();
    $hContent->{'costPrice'} = {
            'amount' => $self->costPrice(),
            'currencyId' => $self->currencyCode,
    } if defined $self->costPrice();
    $hContent->{'vatPercentage'} = $self->vatPercentage() if $self->vatPercentage();
    $hContent->{'options'} = $self->options() if $self->options();
    $hContent->{'presentation'} = $self->presentation() if $self->presentation();

    return $hContent;
}

1;