# CONTENTS
This document contains extracts from a private document shared by Zettle to help with the development:
```
iZettle Partner Integrations: Solution Documentation
```

Document is being updated on a regular basis so, if required, request the latest version from Zettle.
Latest version as of June 2021 is version 0.9.1 (15 April 2021).

# EXTRACTS

## 4.4.1.1. Taxation Types
Integrations should use the tax settings information provided by the Account Information API to
determine which VAT/tax model to use when synchronizing products and their prices.
- taxationType == NONE

  The account doesn?t apply VAT or sales tax to the product prices.
- taxationType == VAT

  This account uses country-specific VAT rates. The response will also include a field
*vatPercentage* with the default VAT rate for the iZettle merchant?s country.
- taxationType == SALES_TAX

  This account uses sales tax rates that are set up and managed by the merchant in the iZettle
Backoffice. Information about the available sales tax rates in the merchant?s iZettle account can
be retrieved with the Product Library API?s Sales Tax Rates endpoints.

The previously used field usesVAT is redundant with taxationType == VAT, it is
recommended to check the taxationType value instead.

## 4.4.1.2. Price Types
The Account Information API response also includes information about the user?s settings for the
price structure of the iZettle product library:
- taxationMode == INCLUSIVE

  Product prices in the iZettle Product Library are inclusive taxes (net prices)
- taxationMode == EXCLUSIVE

  Product prices in the iZettle Product Library are exclusive taxes (gross prices)

Note that this setting only provides information how product prices are stored. It in particular does
not make a statement wether the merchant collects taxes at all, or which tax rates will be applied to
which product (see VAT and Sales Tax).

## 4.4.2. Retrieve a Merchant's Account Information
```
GET /api/resources/organizations/self HTTP/1.1
Host: secure.izettle.com
Authorization: Bearer eyJraWQiOiIxN...R5Y6FDNTva7esJ5Q
```

Sample response:
```
{
    "uuid": "1a52e2a8-824d-11eb-acc8-aafa2648b59f",
    "name": "Earl of Pages",
    "city": "Jaywick",
    "zipCode": "AB123CD",
    "address": "71 Hooligan Street 2",
    "addressLine2": "",
    "legalName": "",
    "legalAddress": "",
    "legalAddressLine2": "",
    "legalZipCode": "",
    "legalCity": "",
    "legalState": "",
    "phoneNumber": "+447853826127",
    "contactEmail": "test-epages-gb-1@izettle.com",
    "receiptEmail": "test-epages-gb-1@izettle.com",
    "legalEntityType": "COMPANY",
    "legalEntityNr": "NI482452",
    "vatPercentage": 20.0,
    "country": "GB",
    "language": "en",
    "currency": "GBP",
    "created": "2021-03-11T09:35:23.066+0000",
    "ownerUuid": "1a5431c6-824d-11eb-92c1-8c85ccaff8db",
    "organizationId": 70063314,
    "customerStatus": "PAUSED",
    "usesVat": true,
    "customerType": "LimitedCompany",
    "taxationType": "VAT",
    "taxationMode": "INCLUSIVE",
    "timeZone": "Europe/London"
}
```